Ordered

Struct Ordered 

pub struct Ordered<const N: usize, const SHAPE: u32> { /* private fields */ }
A Topology whose nodes are topologically sorted by their deps: edges.

Implementations

Source

impl<const N: usize, const SHAPE: u32> Ordered<N, SHAPE>

pub const fn new(deps: &'static [&'static [u8]; N]) -> Self

Build a topology from a static array of dependency lists.