compose_graph

Macro compose_graph 

macro_rules! compose_graph {
    (name: $n:ident, fragments: [$f:path $(, $r:path)* $(,)?], graph: {$($g:tt)*}) => { ... };
    (fragments: [$f:path $(, $r:path)* $(,)?], graph: {$($g:tt)*}) => { ... };
    (@next [], {$($acc:tt)*}, {$($g:tt)*}) => { ... };
    (@next [$f:path $(, $r:path)*], {$($acc:tt)*}, $g:tt) => { ... };
}
Compose a graph out of one or more supervisor_fragment! declarations.

The fragments are spliced into the final graph at the compose site. This macro is re-exported by embassy-supervisor when the macros feature is enabled.