pub struct Coupling { /* private fields */ }Expand description
A declared read/write coupling between a node and a signal.
Implementations
Sourceimpl Coupling
impl Coupling
Sourcepub const fn new(name: &'static str, point: &'static dyn CouplingPoint) -> Self
pub const fn new(name: &'static str, point: &'static dyn CouplingPoint) -> Self
Create a coupling with the given path name and wiring point.
Sourcepub const fn veto(self, slot: u8) -> Self
pub const fn veto(self, slot: u8) -> Self
Mark this coupling as a veto write holding contributor slot.
Sourcepub const fn veto_slot(&self) -> Option<u8>
pub const fn veto_slot(&self) -> Option<u8>
This writer’s contributor slot, if the entry carries the veto marker.
Sourcepub const fn observed(self, observer: Observer) -> Self
pub const fn observed(self, observer: Observer) -> Self
Mark this coupling as observed with the given observer.