pub struct Leased<T> { /* private fields */ }Expand description
A signal-like value whose producer can wait until all outstanding readers finish.
Leased counts live claims; drain blocks until the count
reaches zero, which is used to hold a producer’s stop until consumers are done.
Implementations